@@ -1,2 +1,2 @@
 from polyscope_persistence.wrapper import PolyscopeObject, PolyscopeMesh, PolyscopePointcloud, PolyscopeVectorQuantity, \
-    PolyscopeScalarQuantity
+    PolyscopeScalarQuantity, PolyscopeCurvenetwork
